/*
** iplog_pcap.h - iplog pcap management data.
** Copyright (C) 1999 Odin <odin@numb.org>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License, version 2,
** as published by the Free Software Foundation.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
*/

#ifndef __IPLOG_PCAP_H
#define __IPLOG_PCAP_H

#include <net/if.h>

#ifdef __linux__
#	include <linux/if_ether.h>
#else
#	include <netinet/if_ether.h>
#	define ethhdr	ether_header
#endif /* ! linux */

#ifndef DLT_RAW
#	define DLT_RAW			12
#endif

#ifndef DLT_SLIP_BSDOS
#	define DLT_SLIP_BSDOS	13
#endif

#ifndef DLT_PPP_BSDOS
#	define DLT_PPP_BSDOS	14
#endif

#ifndef IP_OFFMASK
#	define IP_OFFMASK 0x1fff
#endif

#define LOOPBACK(x) \
	(!strncasecmp(x, "lo", 2) && ((x)[2] == '\0' || isdigit((x)[2])))

#define FRAG_MAX 5
#define FRAG_TSIZE 64
#define FRAG_TTL 60

/* temporary, this can surely be improved */
#define FRAGHASH(a, b, c, d) ((a^b^c^d) & (FRAG_TSIZE - 1))

struct iff_data {
	struct iff_data *next;
	u_char name[64];
	u_long addr[16];
	u_int n_addr;
};

struct pcap_data {
	struct pcap_data *next;
	pcap_t *pd;
	int dl;
}; 

struct frag_data {
	struct frag_data *next;
	u_char prot;
	u_char rf;
	u_short id;
	u_long s_addr;
	u_long d_addr;
	time_t expire;
	u_long bytes;
	u_long t_len;
	struct ip header;
	struct ip_fragment {
		struct ip_fragment *next;
		u_char *data;
		u_int off;
		u_int len;
	} *frag;
	pthread_mutex_t lock;
};

struct frag_list {
	struct frag_data *head;
	u_int count;
	pthread_mutex_t lock;
};

int setup_pcap(struct pcap_data **plist, const u_char *ifstring);
void deallocate_frags(struct frag_data *fl, u_long hash);
void frag_cleanup(void *frag);
void destroy_frag_table(void);
void expire_frags(void);
void parse_packet(struct ip *ip);
struct ip *iplog_reassemble(const struct frag_data *fl);
#endif /* __IPLOG_PCAP_H */

/* vim:ts=4:sw=8:tw=0 */
